@@ -21,21 +21,22 @@ import (
 	"github.com/gruntwork-io/terragrunt/cli/commands/backend"
 	"github.com/gruntwork-io/terragrunt/cli/commands/catalog"
 	"github.com/gruntwork-io/terragrunt/cli/commands/dag"
-	execCmd "github.com/gruntwork-io/terragrunt/cli/commands/exec"
+	execcmd "github.com/gruntwork-io/terragrunt/cli/commands/exec"
 	"github.com/gruntwork-io/terragrunt/cli/commands/find"
 	"github.com/gruntwork-io/terragrunt/cli/commands/hcl"
-	helpCmd "github.com/gruntwork-io/terragrunt/cli/commands/help"
+	helpcmd "github.com/gruntwork-io/terragrunt/cli/commands/help"
 	"github.com/gruntwork-io/terragrunt/cli/commands/info"
 	"github.com/gruntwork-io/terragrunt/cli/commands/list"
 	"github.com/gruntwork-io/terragrunt/cli/commands/render"
-	runCmd "github.com/gruntwork-io/terragrunt/cli/commands/run"
+	runcmd "github.com/gruntwork-io/terragrunt/cli/commands/run"
 	"github.com/gruntwork-io/terragrunt/cli/commands/scaffold"
 	"github.com/gruntwork-io/terragrunt/cli/commands/stack"
-	versionCmd "github.com/gruntwork-io/terragrunt/cli/commands/version"
+	versioncmd "github.com/gruntwork-io/terragrunt/cli/commands/version"
 	"github.com/gruntwork-io/terragrunt/config"
 	"github.com/gruntwork-io/terragrunt/internal/cli"
 	"github.com/gruntwork-io/terragrunt/internal/errors"
 	"github.com/gruntwork-io/terragrunt/internal/os/exec"
+	"github.com/gruntwork-io/terragrunt/internal/runner/run"
 	"github.com/gruntwork-io/terragrunt/pkg/log/format/placeholders"
 	"github.com/gruntwork-io/terragrunt/telemetry"
 	"github.com/hashicorp/go-version"
@@ -59,9 +60,9 @@ const (
 // Categories are ordered in increments of 10 for easy insertion of new categories.
 func New(l log.Logger, opts *options.TerragruntOptions) cli.Commands {
 	mainCommands := cli.Commands{
-		runCmd.NewCommand(l, opts),  // run
+		runcmd.NewCommand(l, opts),  // run
 		stack.NewCommand(l, opts),   // stack
-		execCmd.NewCommand(l, opts), // exec
+		execcmd.NewCommand(l, opts), // exec
 		backend.NewCommand(l, opts), // backend
 	}.SetCategory(
 		&cli.Category{
@@ -95,8 +96,8 @@ func New(l log.Logger, opts *options.TerragruntOptions) cli.Commands {
 		info.NewCommand(l, opts),             // info
 		dag.NewCommand(l, opts),              // dag
 		render.NewCommand(l, opts),           // render
-		helpCmd.NewCommand(l, opts),          // help (hidden)
-		versionCmd.NewCommand(opts),          // version (hidden)
+		helpcmd.NewCommand(l, opts),          // help (hidden)
+		versioncmd.NewCommand(opts),          // version (hidden)
 		awsproviderpatch.NewCommand(l, opts), // aws-provider-patch (hidden)
 	}.SetCategory(
 		&cli.Category{
@@ -205,7 +206,7 @@ func setupAutoProviderCacheDir(ctx context.Context, l log.Logger, opts *options.
 
 	var err error
 
-	l, terraformVersion, tfImplementation, err := runCmd.GetTFVersion(ctx, l, opts)
+	l, terraformVersion, tfImplementation, err := run.GetTFVersion(ctx, l, opts)
 	if err != nil {
 		return err
 	}
@@ -275,7 +276,7 @@ func initialSetup(cliCtx *cli.Context, l log.Logger, opts *options.TerragruntOpt
 	args := cliCtx.Args().WithoutBuiltinCmdSep().Normalize(cli.SingleDashFlag)
 	cmdName := cliCtx.Command.Name
 
-	if cmdName == runCmd.CommandName {
+	if cmdName == runcmd.CommandName {
 		cmdName = args.CommandName()
 	} else {
 		args = append([]string{cmdName}, args...)
@@ -345,7 +346,7 @@ func initialSetup(cliCtx *cli.Context, l log.Logger, opts *options.TerragruntOpt
 	if opts.TerragruntConfigPath == "" {
 		opts.TerragruntConfigPath = config.GetDefaultConfigPath(opts.WorkingDir)
 	} else if !filepath.IsAbs(opts.TerragruntConfigPath) &&
-		(cliCtx.Command.Name == runCmd.CommandName || slices.Contains(tf.CommandNames, cliCtx.Command.Name)) {
+		(cliCtx.Command.Name == runcmd.CommandName || slices.Contains(tf.CommandNames, cliCtx.Command.Name)) {
 		opts.TerragruntConfigPath = util.JoinPath(opts.WorkingDir, opts.TerragruntConfigPath)
 	}
 
@@ -433,7 +434,7 @@ func initialSetup(cliCtx *cli.Context, l log.Logger, opts *options.TerragruntOpt
 	opts.OriginalTerraformCommand = opts.TerraformCommand
 	opts.OriginalIAMRoleOptions = opts.IAMRoleOptions
 
-	opts.RunTerragrunt = runCmd.Run
+	opts.RunTerragrunt = run.Run
 
 	exec.PrepareConsole(l)
 
